Learn R Programming

CoFM (version 1.1.4)

air_quality: Air Quality Data Set

Description

Air quality measurements collected from a gas multisensor device deployed in an Italian city.

This dataset contains the responses of a gas multisensor device deployed on the field in an Italian city.

Usage

air_quality

air_quality

Arguments

Format

A data frame with 9358 rows and 14 variables:

DateTime

Date and time of the measurement (POSIXct).

CO_GT

True hourly averaged CO concentration in \(mg/m^3\) (reference analyzer).

PT08_S1_CO

PT08.S1 (tin oxide) hourly averaged sensor response (CO targeted).

NMHC_GT

True hourly averaged non-methanic hydrocarbons concentration in \(\mu g/m^3\).

C6H6_GT

True hourly averaged benzene concentration in \(\mu g/m^3\).

PT08_S2_NMHC

PT08.S2 (titania) hourly averaged sensor response (NMHC targeted).

NOx_GT

True hourly averaged NOx concentration in ppb.

PT08_S3_NOx

PT08.S3 (tungsten oxide) hourly averaged sensor response (NOx targeted).

NO2_GT

True hourly averaged NO2 concentration in \(\mu g/m^3\).

PT08_S4_NO2

PT08.S4 (tungsten oxide) hourly averaged sensor response (NO2 targeted).

PT08_S5_O3

PT08.S5 (indium oxide) hourly averaged sensor response (O3 targeted).

T

Temperature in degrees Celsius.

RH

Relative humidity (percent).

AH

Absolute humidity.

A data frame with 9357 rows and 16 variables.

Details

The dataset was collected from March 2004 to February 2005. Missing values are tagged with -200 value in the raw data, but have been converted to NA.