Air quality measurements collected from a gas multisensor device deployed in an Italian city.
This dataset contains the responses of a gas multisensor device deployed on the field in an Italian city.
air_qualityair_quality
A data frame with 9358 rows and 14 variables:
DateTimeDate and time of the measurement (POSIXct).
CO_GTTrue hourly averaged CO concentration in \(mg/m^3\) (reference analyzer).
PT08_S1_COPT08.S1 (tin oxide) hourly averaged sensor response (CO targeted).
NMHC_GTTrue hourly averaged non-methanic hydrocarbons concentration in \(\mu g/m^3\).
C6H6_GTTrue hourly averaged benzene concentration in \(\mu g/m^3\).
PT08_S2_NMHCPT08.S2 (titania) hourly averaged sensor response (NMHC targeted).
NOx_GTTrue hourly averaged NOx concentration in ppb.
PT08_S3_NOxPT08.S3 (tungsten oxide) hourly averaged sensor response (NOx targeted).
NO2_GTTrue hourly averaged NO2 concentration in \(\mu g/m^3\).
PT08_S4_NO2PT08.S4 (tungsten oxide) hourly averaged sensor response (NO2 targeted).
PT08_S5_O3PT08.S5 (indium oxide) hourly averaged sensor response (O3 targeted).
TTemperature in degrees Celsius.
RHRelative humidity (percent).
AHAbsolute humidity.
A data frame with 9357 rows and 16 variables.
The dataset was collected from March 2004 to February 2005. Missing values are tagged with -200 value in the raw data, but have been converted to NA.